@@ -1,23 +1,28 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import datetime
 import logging as std_logging
 import operator
+import unittest
 from decimal import Decimal
 
 import elasticsearch
+from django.apps import apps
 from django.conf import settings
 from django.test import TestCase
 from django.test.utils import override_settings
-from django.utils import unittest
+
 from haystack import connections, indexes, reset_search_queries
+from haystack.exceptions import SkipDocument
 from haystack.inputs import AutoQuery
 from haystack.models import SearchResult
-from haystack.query import RelatedSearchQuerySet, SearchQuerySet, SQ
+from haystack.query import SQ, RelatedSearchQuerySet, SearchQuerySet
 from haystack.utils import log as logging
+from haystack.utils.geo import Point
 from haystack.utils.loading import UnifiedIndex
 
-from ..core.models import (AFourthMockModel, AnotherMockModel, ASixthMockModel,
-                           MockModel)
+from ..core.models import AFourthMockModel, AnotherMockModel, ASixthMockModel, MockModel
 from ..mocks import MockSearchResult
 
 test_pickling = True
@@ -40,20 +45,32 @@ def clear_elasticsearch_index():
     except elasticsearch.TransportError:
         pass
 
+    # Since we've just completely deleted the index, we'll reset setup_complete so the next access will
+    # correctly define the mappings:
+    connections['elasticsearch'].get_backend().setup_complete = False
+
 
 class ElasticsearchMockSearchIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True, use_template=True)
     name = indexes.CharField(model_attr='author', faceted=True)
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
 
     def get_model(self):
         return MockModel
 
 
+class ElasticsearchMockSearchIndexWithSkipDocument(ElasticsearchMockSearchIndex):
+
+    def prepare_text(self, obj):
+        if obj.author == 'daniel3':
+            raise SkipDocument
+        return u"Indexed!\n%s" % obj.id
+
+
 class ElasticsearchMockSpellingIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True)
     name = indexes.CharField(model_attr='author', faceted=True)
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
 
     def get_model(self):
         return MockModel
@@ -65,7 +82,7 @@ class ElasticsearchMockSpellingIndex(indexes.SearchIndex, indexes.Indexable):
 class ElasticsearchMaintainTypeMockSearchIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True, use_template=True)
     month = indexes.CharField(indexed=False)
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
 
     def prepare_month(self, obj):
         return "%02d" % obj.pub_date.month
@@ -77,7 +94,7 @@ class ElasticsearchMaintainTypeMockSearchIndex(indexes.SearchIndex, indexes.Inde
 class ElasticsearchMockModelSearchIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(model_attr='foo', document=True)
     name = indexes.CharField(model_attr='author')
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
 
     def get_model(self):
         return MockModel
@@ -86,7 +103,7 @@ class ElasticsearchMockModelSearchIndex(indexes.SearchIndex, indexes.Indexable):
 class ElasticsearchAnotherMockModelSearchIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True)
     name = indexes.CharField(model_attr='author')
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
 
     def get_model(self):
         return AnotherMockModel
@@ -102,7 +119,7 @@ class ElasticsearchBoostMockSearchIndex(indexes.SearchIndex, indexes.Indexable):
     )
     author = indexes.CharField(model_attr='author', weight=2.0)
     editor = indexes.CharField(model_attr='editor')
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
 
     def get_model(self):
         return AFourthMockModel
@@ -180,7 +197,7 @@ class ElasticsearchComplexFacetsMockSearchIndex(indexes.SearchIndex, indexes.Ind
 class ElasticsearchAutocompleteMockModelSearchIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(model_attr='foo', document=True)
     name = indexes.CharField(model_attr='author')
-    pub_date = indexes.DateField(model_attr='pub_date')
+    pub_date = indexes.DateTimeField(model_attr='pub_date')
     text_auto = indexes.EdgeNgramField(model_attr='foo')
     name_auto = indexes.EdgeNgramField(model_attr='author')
 
@@ -198,13 +215,20 @@ class ElasticsearchSpatialSearchIndex(indexes.SearchIndex, indexes.Indexable):
     def get_model(self):
         return ASixthMockModel
 
+
 class TestSettings(TestCase):
+
     def test_kwargs_are_passed_on(self):
         from haystack.backends.elasticsearch_backend import ElasticsearchSearchBackend
-        backend = ElasticsearchSearchBackend('alias', **{'URL': {}, 'INDEX_NAME': 'testing', 'KWARGS': {'max_retries': 42}})
+        backend = ElasticsearchSearchBackend('alias', **{
+            'URL': settings.HAYSTACK_CONNECTIONS['elasticsearch']['URL'],
+            'INDEX_NAME': 'testing',
+            'KWARGS': {'max_retries': 42}
+        })
 
         self.assertEqual(backend.conn.transport.max_retries, 42)
 
+
 class ElasticsearchSearchBackendTestCase(TestCase):
     def setUp(self):
         super(ElasticsearchSearchBackendTestCase, self).setUp()
@@ -217,6 +241,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
         self.old_ui = connections['elasticsearch'].get_unified_index()
         self.ui = UnifiedIndex()
         self.smmi = ElasticsearchMockSearchIndex()
+        self.smmidni = ElasticsearchMockSearchIndexWithSkipDocument()
         self.smtmmi = ElasticsearchMaintainTypeMockSearchIndex()
         self.ui.build(indexes=[self.smmi])
         connections['elasticsearch']._index = self.ui
@@ -322,6 +347,18 @@ class ElasticsearchSearchBackendTestCase(TestCase):
             }
         ])
 
+    def test_update_with_SkipDocument_raised(self):
+        self.sb.update(self.smmidni, self.sample_objs)
+
+        # Check what Elasticsearch thinks is there.
+        res = self.raw_search('*:*')['hits']
+        self.assertEqual(res['total'], 2)
+        self.assertListEqual(
+            sorted([x['_source']['id'] for x in res['hits']]),
+            ['core.mockmodel.1', 'core.mockmodel.2']
+        )
+
+
     def test_remove(self):
         self.sb.update(self.smmi, self.sample_objs)
         self.assertEqual(self.raw_search('*:*')['hits']['total'], 3)
@@ -386,7 +423,10 @@ class ElasticsearchSearchBackendTestCase(TestCase):
         self.assertEqual(self.sb.search('', highlight=True), {'hits': 0, 'results': []})
         self.assertEqual(self.sb.search('Index', highlight=True)['hits'], 3)
         self.assertEqual(sorted([result.highlighted[0] for result in self.sb.search('Index', highlight=True)['results']]),
-            [u'<em>Indexed</em>!\n1', u'<em>Indexed</em>!\n2', u'<em>Indexed</em>!\n3'])
+                         [u'<em>Indexed</em>!\n1', u'<em>Indexed</em>!\n2', u'<em>Indexed</em>!\n3'])
+        self.assertEqual(sorted([result.highlighted[0] for result in self.sb.search('Index', highlight={'pre_tags': ['<start>'],'post_tags': ['</end>']})['results']]),
+                         [u'<start>Indexed</end>!\n1', u'<start>Indexed</end>!\n2', u'<start>Indexed</end>!\n3'])
+
 
         self.assertEqual(self.sb.search('Indx')['hits'], 0)
         self.assertEqual(self.sb.search('indaxed')['spelling_suggestion'], 'indexed')
@@ -430,6 +470,21 @@ class ElasticsearchSearchBackendTestCase(TestCase):
         # Restore.
         settings.HAYSTACK_LIMIT_TO_REGISTERED_MODELS = old_limit_to_registered_models
 
+    def test_spatial_search_parameters(self):
+        p1 = Point(1.23, 4.56)
+        kwargs = self.sb.build_search_kwargs('*:*', distance_point={'field': 'location', 'point': p1},
+                                             sort_by=(('distance', 'desc'), ))
+
+        self.assertIn('sort', kwargs)
+        self.assertEqual(1, len(kwargs['sort']))
+        geo_d = kwargs['sort'][0]['_geo_distance']
+
+        # ElasticSearch supports the GeoJSON-style lng, lat pairs so unlike Solr the values should be
+        # in the same order as we used to create the Point():
+        # http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-geo-distance-filter.html#_lat_lon_as_array_4
+
+        self.assertDictEqual(geo_d, {'location': [1.23, 4.56], 'unit': 'km', 'order': 'desc'})
+
     def test_more_like_this(self):
         self.sb.update(self.smmi, self.sample_objs)
         self.assertEqual(self.raw_search('*:*')['hits']['total'], 3)
@@ -444,7 +499,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
 
         (content_field_name, mapping) = self.sb.build_schema(old_ui.all_searchfields())
         self.assertEqual(content_field_name, 'text')
-        self.assertEqual(len(mapping), 4+2) # +2 management fields
+        self.assertEqual(len(mapping), 4 + 2)  # +2 management fields
         self.assertEqual(mapping, {
             'django_id': {'index': 'not_analyzed', 'type': 'string', 'include_in_all': False},
             'django_ct': {'index': 'not_analyzed', 'type': 'string', 'include_in_all': False},
@@ -458,7 +513,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
         ui.build(indexes=[ElasticsearchComplexFacetsMockSearchIndex()])
         (content_field_name, mapping) = self.sb.build_schema(ui.all_searchfields())
         self.assertEqual(content_field_name, 'text')
-        self.assertEqual(len(mapping), 15+2) # +2 management fields
+        self.assertEqual(len(mapping), 15 + 2)  # +2 management fields
         self.assertEqual(mapping, {
             'django_id': {'index': 'not_analyzed', 'type': 'string', 'include_in_all': False},
             'django_ct': {'index': 'not_analyzed', 'type': 'string', 'include_in_all': False},
@@ -518,8 +573,8 @@ class FailedElasticsearchSearchBackendTestCase(TestCase):
         settings.HAYSTACK_CONNECTIONS['elasticsearch']['URL'] = "%s/foo/" % self.old_es_url
         self.cap = CaptureHandler()
         logging.getLogger('haystack').addHandler(self.cap)
-        import haystack
-        logging.getLogger('haystack').removeHandler(haystack.stream)
+        config = apps.get_app_config('haystack')
+        logging.getLogger('haystack').removeHandler(config.stream)
 
         # Setup the rest of the bits.
         self.old_ui = connections['elasticsearch'].get_unified_index()
@@ -530,12 +585,12 @@ class FailedElasticsearchSearchBackendTestCase(TestCase):
         self.sb = connections['elasticsearch'].get_backend()
 
     def tearDown(self):
-        import haystack
         # Restore.
         settings.HAYSTACK_CONNECTIONS['elasticsearch']['URL'] = self.old_es_url
         connections['elasticsearch']._index = self.old_ui
+        config = apps.get_app_config('haystack')
         logging.getLogger('haystack').removeHandler(self.cap)
-        logging.getLogger('haystack').addHandler(haystack.stream)
+        logging.getLogger('haystack').addHandler(config.stream)
 
     @unittest.expectedFailure
     def test_all_cases(self):
@@ -562,7 +617,7 @@ class FailedElasticsearchSearchBackendTestCase(TestCase):
 
 
 class LiveElasticsearchSearchQueryTestCase(TestCase):
-    fixtures = ['initial_data.json']
+    fixtures = ['base_data.json']
 
     def setUp(self):
         super(LiveElasticsearchSearchQueryTestCase, self).setUp()
@@ -587,7 +642,6 @@ class LiveElasticsearchSearchQueryTestCase(TestCase):
         super(LiveElasticsearchSearchQueryTestCase, self).tearDown()
 
     def test_log_query(self):
-        from django.conf import settings
         reset_search_queries()
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
 
@@ -622,7 +676,7 @@ lssqstc_all_loaded = None
 @override_settings(DEBUG=True)
 class LiveElasticsearchSearchQuerySetTestCase(TestCase):
     """Used to test actual implementation details of the SearchQuerySet."""
-    fixtures = ['bulk_data.json']
+    fixtures = ['base_data.json', 'bulk_data.json']
 
     def setUp(self):
         super(LiveElasticsearchSearchQuerySetTestCase, self).setUp()
@@ -664,9 +718,9 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         reset_search_queries()
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         sqs = self.sqs.all()
-        results = sorted([int(result.pk) for result in sqs])
+        results = sorted([int(result.pk) for result in list(sqs)])
         self.assertEqual(results, list(range(1, 24)))
-        self.assertEqual(len(connections['elasticsearch'].queries), 3)
+        self.assertEqual(len(connections['elasticsearch'].queries), 4)
 
     def test_slice(self):
         reset_search_queries()
@@ -681,6 +735,27 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         self.assertEqual(int(results[21].pk), 22)
         self.assertEqual(len(connections['elasticsearch'].queries), 1)
 
+    def test_values_slicing(self):
+        reset_search_queries()
+        self.assertEqual(len(connections['elasticsearch'].queries), 0)
+
+        # TODO: this would be a good candidate for refactoring into a TestCase subclass shared across backends
+
+        # The values will come back as strings because Hasytack doesn't assume PKs are integers.
+        # We'll prepare this set once since we're going to query the same results in multiple ways:
+        expected_pks = [str(i) for i in [3, 2, 4, 5, 6, 7, 8, 9, 10, 11]]
+
+        results = self.sqs.all().order_by('pub_date').values('pk')
+        self.assertListEqual([i['pk'] for i in results[1:11]], expected_pks)
+
+        results = self.sqs.all().order_by('pub_date').values_list('pk')
+        self.assertListEqual([i[0] for i in results[1:11]], expected_pks)
+
+        results = self.sqs.all().order_by('pub_date').values_list('pk', flat=True)
+        self.assertListEqual(results[1:11], expected_pks)
+
+        self.assertEqual(len(connections['elasticsearch'].queries), 3)
+
     def test_count(self):
         reset_search_queries()
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
@@ -692,6 +767,17 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         # Should only execute one query to count the length of the result set.
         self.assertEqual(len(connections['elasticsearch'].queries), 1)
 
+    def test_highlight(self):
+        reset_search_queries()
+        results = self.sqs.filter(content='index').highlight()
+        self.assertEqual(results[0].highlighted, [u'<em>Indexed</em>!\n1'])
+
+    def test_highlight_options(self):
+        reset_search_queries()
+        results = self.sqs.filter(content='index')
+        results = results.highlight(pre_tags=['<i>'], post_tags=['</i>'])
+        self.assertEqual(results[0].highlighted, [u'<i>Indexed</i>!\n1'])
+
     def test_manual_iter(self):
         results = self.sqs.all()
 
@@ -719,9 +805,10 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         self.assertEqual(self.sqs._cache_is_full(), False)
         results = self.sqs.all()
-        fire_the_iterator_and_fill_cache = [result for result in results]
+        fire_the_iterator_and_fill_cache = list(results)
+        self.assertEqual(23, len(fire_the_iterator_and_fill_cache))
         self.assertEqual(results._cache_is_full(), True)
-        self.assertEqual(len(connections['elasticsearch'].queries), 3)
+        self.assertEqual(len(connections['elasticsearch'].queries), 4)
 
     def test___and__(self):
         sqs1 = self.sqs.filter(content='foo')
@@ -768,9 +855,19 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         self.assertEqual(sqs.query.build_query(), u'("pants\\:rule")')
         self.assertEqual(len(sqs), 0)
 
+    def test_query__in(self):
+        self.assertGreater(len(self.sqs), 0)
+        sqs = self.sqs.filter(django_ct='core.mockmodel', django_id__in=[1, 2])
+        self.assertEqual(len(sqs), 2)
+
+    def test_query__in_empty_list(self):
+        """Confirm that an empty list avoids a Elasticsearch exception"""
+        self.assertGreater(len(self.sqs), 0)
+        sqs = self.sqs.filter(id__in=[])
+        self.assertEqual(len(sqs), 0)
+
     # Regressions
 
-    @unittest.expectedFailure
     def test_regression_proper_start_offsets(self):
         sqs = self.sqs.filter(text='index')
         self.assertNotEqual(sqs.count(), 0)
@@ -823,7 +920,7 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         reset_search_queries()
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         sqs = self.rsqs.all()
-        results = set([int(result.pk) for result in sqs])
+        results = set([int(result.pk) for result in list(sqs)])
         self.assertEqual(results, set([2, 7, 12, 17, 1, 6, 11, 16, 23, 5, 10, 15, 22, 4, 9, 14, 19, 21, 3, 8, 13, 18, 20]))
         self.assertEqual(len(connections['elasticsearch'].queries), 4)
 
@@ -832,19 +929,19 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         results = self.rsqs.all().order_by('pub_date')
         self.assertEqual([int(result.pk) for result in results[1:11]], [3, 2, 4, 5, 6, 7, 8, 9, 10, 11])
-        self.assertEqual(len(connections['elasticsearch'].queries), 3)
+        self.assertEqual(len(connections['elasticsearch'].queries), 1)
 
         reset_search_queries()
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         results = self.rsqs.all().order_by('pub_date')
         self.assertEqual(int(results[21].pk), 22)
-        self.assertEqual(len(connections['elasticsearch'].queries), 4)
+        self.assertEqual(len(connections['elasticsearch'].queries), 1)
 
         reset_search_queries()
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         results = self.rsqs.all().order_by('pub_date')
         self.assertEqual(set([int(result.pk) for result in results[20:30]]), set([21, 22, 23]))
-        self.assertEqual(len(connections['elasticsearch'].queries), 4)
+        self.assertEqual(len(connections['elasticsearch'].queries), 1)
 
     def test_related_manual_iter(self):
         results = self.rsqs.all()
@@ -853,7 +950,7 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         results = sorted([int(result.pk) for result in results._manual_iter()])
         self.assertEqual(results, list(range(1, 24)))
-        self.assertEqual(len(connections['elasticsearch'].queries), 4)
+        self.assertEqual(len(connections['elasticsearch'].queries), 3)
 
     def test_related_fill_cache(self):
         reset_search_queries()
@@ -873,9 +970,10 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
         self.assertEqual(len(connections['elasticsearch'].queries), 0)
         self.assertEqual(self.rsqs._cache_is_full(), False)
         results = self.rsqs.all()
-        fire_the_iterator_and_fill_cache = [result for result in results]
+        fire_the_iterator_and_fill_cache = list(results)
+        self.assertEqual(23, len(fire_the_iterator_and_fill_cache))
         self.assertEqual(results._cache_is_full(), True)
-        self.assertEqual(len(connections['elasticsearch'].queries), 5)
+        self.assertEqual(len(connections['elasticsearch'].queries), 4)
 
     def test_quotes_regression(self):
         sqs = self.sqs.auto_query(u"44°48'40''N 20°28'32''E")
@@ -945,7 +1043,7 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
 @override_settings(DEBUG=True)
 class LiveElasticsearchSpellingTestCase(TestCase):
     """Used to test actual implementation details of the SearchQuerySet."""
-    fixtures = ['bulk_data.json']
+    fixtures = ['base_data.json', 'bulk_data.json']
 
     def setUp(self):
         super(LiveElasticsearchSpellingTestCase, self).setUp()
@@ -979,9 +1077,12 @@ class LiveElasticsearchSpellingTestCase(TestCase):
         self.assertEqual(self.sqs.auto_query('srchindex instanc').spelling_suggestion(), 'searchindex instance')
         self.assertEqual(self.sqs.spelling_suggestion('srchindex instanc'), 'searchindex instance')
 
+        sqs = self.sqs.auto_query('something completely different').set_spelling_query('structurd')
+        self.assertEqual(sqs.spelling_suggestion(), 'structured')
+
 
 class LiveElasticsearchMoreLikeThisTestCase(TestCase):
-    fixtures = ['bulk_data.json']
+    fixtures = ['base_data.json', 'bulk_data.json']
 
     def setUp(self):
         super(LiveElasticsearchMoreLikeThisTestCase, self).setUp()
@@ -1001,13 +1102,11 @@ class LiveElasticsearchMoreLikeThisTestCase(TestCase):
         self.smmi.update(using='elasticsearch')
         self.sammi.update(using='elasticsearch')
 
-
     def tearDown(self):
         # Restore.
         connections['elasticsearch']._index = self.old_ui
         super(LiveElasticsearchMoreLikeThisTestCase, self).tearDown()
 
-    @unittest.expectedFailure
     def test_more_like_this(self):
         mlt = self.sqs.more_like_this(MockModel.objects.get(pk=1))
         self.assertEqual(mlt.count(), 4)
@@ -1037,9 +1136,8 @@ class LiveElasticsearchMoreLikeThisTestCase(TestCase):
         self.assertTrue(isinstance(self.sqs.result_class(MockSearchResult).more_like_this(MockModel.objects.get(pk=1))[0], MockSearchResult))
 
 
-
 class LiveElasticsearchAutocompleteTestCase(TestCase):
-    fixtures = ['bulk_data.json']
+    fixtures = ['base_data.json', 'bulk_data.json']
 
     def setUp(self):
         super(LiveElasticsearchAutocompleteTestCase, self).setUp()
@@ -1122,6 +1220,16 @@ class LiveElasticsearchAutocompleteTestCase(TestCase):
         self.assertEqual(set([result.pk for result in autocomplete_3]), set(['12', '1', '22', '14']))
         self.assertEqual(len([result.pk for result in autocomplete_3]), 4)
 
+        # Test numbers in phrases
+        autocomplete_4 = self.sqs.autocomplete(text_auto='Jen 867')
+        self.assertEqual(autocomplete_4.count(), 1)
+        self.assertEqual(set([result.pk for result in autocomplete_4]), set(['20']))
+
+        # Test numbers alone
+        autocomplete_4 = self.sqs.autocomplete(text_auto='867')
+        self.assertEqual(autocomplete_4.count(), 1)
+        self.assertEqual(set([result.pk for result in autocomplete_4]), set(['20']))
+
 
 class LiveElasticsearchRoundTripTestCase(TestCase):
     def setUp(self):
@@ -1173,7 +1281,7 @@ class LiveElasticsearchRoundTripTestCase(TestCase):
 
 @unittest.skipUnless(test_pickling, 'Skipping pickling tests')
 class LiveElasticsearchPickleTestCase(TestCase):
-    fixtures = ['bulk_data.json']
+    fixtures = ['base_data.json', 'bulk_data.json']
 
     def setUp(self):
         super(LiveElasticsearchPickleTestCase, self).setUp()
@@ -1297,8 +1405,9 @@ class RecreateIndexTestCase(TestCase):
             updated_mapping = self.raw_es.indices.get_mapping(sb.index_name)
         except elasticsearch.NotFoundError:
             self.fail("There is no mapping after recreating the index")
+
         self.assertEqual(original_mapping, updated_mapping,
-            "Mapping after recreating the index differs from the original one")
+                         "Mapping after recreating the index differs from the original one")
 
 
 class ElasticsearchFacetingTestCase(TestCase):
